﻿using System;
using System.Collections.Generic;
using System.Linq;
using SabberStoneCore.Tasks;
using SabberStoneCoreAi.POGame;
using SabberStoneCoreAi.Agent;
using SabberStoneCore.Enums;
using System.Diagnostics;
using System.Text;
using SabberStoneCore.Model;
using SabberStoneCore.Model.Entities;
using SabberStoneCoreAi.Meta;
using SabberStoneCore.Tasks.PlayerTasks;


// Developed by Anonymous Author
namespace SabberStoneCoreAi.Agent
{

	class MyScore : Score.Score
	{
		public int RemainingMana => Controller.RemainingMana;
		public int UsedMana => Controller.UsedMana;
		public int Armer => Controller.Hero.Armor;
		public int OpArmer => Controller.Opponent.Hero.Armor;
		public int BaseMana => Controller.BaseMana;
		public int Turn => Controller.Game.Turn;
		public int BoardZoneCnt => BoardZone.Count;
		public int OpBoardZoneCnt => OpBoardZone.Count;

		public int[,] BoardCoef = new int[10, 21];
		public int[] MinionsCoef = new int[11];

		public const int RemainingManaCoef = 0;
		public const int UsedManaCoef = 1;
		public const int ArmerCoef = 2;
		public const int OpArmerCoef = 3;
		public const int BoardZoneCntCoef = 4;
		public const int OpBoardZoneCntCoef = 5;
		public const int HeroHpCoef = 6;
		public const int OpHeroHpCoef = 7;
		public const int HeroAtkCoef = 8;
		public const int OpHeroAtkCoef = 9;
		public const int HandTotCostCoef = 10;
		public const int HandCntCoef = 11;
		public const int OpHandCntCoef = 12;
		public const int DeckCntCoef = 13;
		public const int OpDeckCntCoef = 14;
		public const int MinionTotAtkCoef = 15;
		public const int OpMinionTotAtkCoef = 16;
		public const int MinionTotHealthCoef = 17;
		public const int OpMinionTotHealthCoef = 18;
		public const int MinionTotHealthTauntCoef = 19;
		public const int OpMinionTotHealthTauntCoef = 20;

		public MyScore(int[,] BoardCoef, int[] MinionsCoef)
		{
			this.BoardCoef = BoardCoef;
			this.MinionsCoef = MinionsCoef;
		}

		public override int Rate()
		{
			if (OpHeroHp < 1)
				return Int32.MaxValue;

			if (HeroHp < 1)
				return Int32.MinValue;

			int result = 0;
			int index = Turn;
			if (index > 9) index = 9;

			result += BoardCoef[index, RemainingManaCoef] * RemainingMana;
			result += BoardCoef[index, UsedManaCoef] * UsedMana;
			result += BoardCoef[index, ArmerCoef] * Armer;
			result += BoardCoef[index, OpArmerCoef] * OpArmer;
			result += BoardCoef[index, BoardZoneCntCoef] * BoardZoneCnt;
			result += BoardCoef[index, OpBoardZoneCntCoef] * OpBoardZoneCnt;
			result += BoardCoef[index, HeroHpCoef] * HeroHp;
			result += BoardCoef[index, OpHeroHpCoef] * OpHeroHp;
			result += BoardCoef[index, HeroAtkCoef] * HeroAtk;
			result += BoardCoef[index, OpHeroAtkCoef] * OpHeroAtk;
			result += BoardCoef[index, HandTotCostCoef] * HandTotCost;
			result += BoardCoef[index, HandCntCoef] * HandCnt;
			result += BoardCoef[index, OpHandCntCoef] * OpHandCnt;
			result += BoardCoef[index, DeckCntCoef] * DeckCnt;
			result += BoardCoef[index, OpDeckCntCoef] * OpDeckCnt;
			result += BoardCoef[index, MinionTotAtkCoef] * MinionTotAtk;
			result += BoardCoef[index, OpMinionTotAtkCoef] * OpMinionTotAtk;
			result += BoardCoef[index, MinionTotHealthCoef] * MinionTotHealth;
			result += BoardCoef[index, OpMinionTotHealthCoef] * OpMinionTotHealth;
			result += BoardCoef[index, MinionTotHealthTauntCoef] * MinionTotHealthTaunt;
			result += BoardCoef[index, OpMinionTotHealthTauntCoef] * OpMinionTotHealthTaunt;

			//FirstPlayerCoef = Coefs[index++];
			//OpHeroCoef = Coefs[index++]; => deck coef

			foreach (Minion m in BoardZone.GetAll())
			{
				if (m != null)
				{
					int cost = m.Cost;
					if (cost > 10) cost = 10;
					result += MinionsCoef[cost];
				}
			}

			foreach (Minion m in OpBoardZone.GetAll())
			{
				if (m != null)
				{
					int cost = m.Cost;
					if (cost > 10) cost = 10;
					result -= MinionsCoef[cost];
				}
			}

			return result;
		}

		public override Func<List<IPlayable>, List<int>> MulliganRule()
		{
			return p => p.Where(t => t.Cost > 3).Select(t => t.Id).ToList();
		}
	};

	class UCTNode
	{
		public double reward;
		public int nj;
		public int j;
		public int N;
		public UCTNode parent;
		public Dictionary<int, UCTNode> childDict;
		public POGame.POGame currentPOGame;
		public PlayerTask option;

		public UCTNode(double reward,
			int nj,
			int j,
			int N,
			UCTNode parent,
			PlayerTask option,
			POGame.POGame poGame,
			Dictionary<int, UCTNode> childDict)
		{
			this.reward = reward;
			this.nj = nj;
			this.j = j;
			this.N = N;
			this.parent = parent;
			this.currentPOGame = poGame;
			this.option = option;
			this.childDict = childDict;
		}

		public UCTNode(SabberStoneCoreAi.POGame.POGame poGame)
		{
			this.reward = 0;
			this.nj = 0;
			this.j = 0;
			this.N = 0;
			this.parent = null;
			this.currentPOGame = poGame;
			this.option = null;
			this.childDict = new Dictionary<int, UCTNode>();
		}

		public UCTNode GetChild(int j)
		{
			UCTNode child = null;
			this.childDict.TryGetValue(j, out child);
			return child;
		}

		public bool IsCurrentPlayerTurnEnd()
		{
			// only remain CONCEDE, END_TURN
			return currentPOGame.CurrentPlayer.Options().Count() == 1 &&
				currentPOGame.CurrentPlayer.Options()[0].PlayerTaskType == PlayerTaskType.END_TURN;
		}

		public bool IsGameOver()
		{
			return currentPOGame.State == State.COMPLETE;
		}

		public UCTNode AddChild(UCTNode parent, PlayerTask option, int j, POGame.POGame simulatedPOGame)
		{
			Debug.Assert(simulatedPOGame != null);
			Debug.Assert(option != null);
			UCTNode newChildNode = new UCTNode(0, 0, j, 0, parent, option, simulatedPOGame, new Dictionary<int, UCTNode>());
			parent.childDict.Add(j, newChildNode);
			return newChildNode;
		}

		public void UpdateReward(double reward)
		{
			this.nj++;
			this.reward += reward;
			this.parent.N += 1;
		}

		public string FullPrint()
		{
			return currentPOGame.FullPrint();
		}

		public string FullPathPrint()
		{
			var str = new StringBuilder();
			UCTNode currentNode = this;
			do
			{
				str.AppendLine(PlayerTaskPrint(currentNode.option));
				currentNode = currentNode.parent;
			} while (currentNode != null);
			return str.ToString();
		}

		public string PlayerTaskPrint(PlayerTask option)
		{
			var str = new StringBuilder();
			if (option != null)
				str.Append($"[{option.Source}][{option.PlayerTaskType}][{option.Target}]");
			return str.ToString();
		}
	};

	class UCTSimulator
	{
		public static int CurrentPredictOpDeckIndex = 0;
		public static List<double[]> Coefs = new List<double[]>
		{
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817},
		new double[] { 8.18139009651699, 30, 28, 10000, 1320, 10000, 706, -7191, -6525, -2430, 4434, 8829, -2228, 1195, 8066, 6626, -4660, -10000, -8647, 7975, -10000, 8461, -10000, 9808, -8232, -10000, -3203, 10000, 1349, -2492, -6844, 8409, 5821, -1488, -9711, -3754, 1726, 5786, -566, 6990, 10000, -4239, -8694, -5123, 4896, 4403, -325, 4545, -3436, -4497, 2641, -8769, -10000, -6406, 150, 10000, -2633, -4883, 2050, 28, 2691, -2553, 3400, -10000, 947, -376, -4479, -10000, -3580, 4691, -6017, -2266, -3051, 6136, 1597, -10000, 6700, -2353, -4171, -5343, 6417, 4173, -748, -6245, 2626, 9891, -2507, 5855, -7639, -10000, -10000, -3346, 3918, -6614, 10000, 2421, -4732, 10000, -9826, 10000, 4144, 3644, -3857, -1888, 997, 111, 10000, 2242, 5646, -10000, -5568, 860, 10000, 5240, 9522, 10000, 5726, -9943, 3986, 4611, -10000, 8616, -4447, -3409, 7384, 10000, 3739, 3429, 8025, -3979, -9289, 5025, -187, 4890, -7164, 4252, -10000, -9880, 6609, 6477, 7313, -4367, -8576, 10000, -3120, 1642, 7168, -2794, 10000, 10000, 5249, -10000, 10000, -6068, -5724, -2757, 10000, -5902, 490, -10000, -9679, 5042, -6682, -9895, -4594, -1221, 568, -8285, -3569, -2599, -5964, 6877, 8940, -5063, 1979, 10000, 1763, 5085, 3136, 139, -10000, 10000, -10000, -6198, -1293, -10000, -3054, -6314, 3602, 8955, 10000, -966, 5218, -2989, -10000, -439, 5252, -1455, -9641, -8558, 425, -4989, -3104, -3128, -4922, -2993, -6042, 2408, -6216, 8626, -2, -4720, -4265, 10000, 7951, 9118, 9993, 1176, 8866, 8789, 2402, 7178, 10000, 10000, 10000, 5817}
		};

		public long maxOptionCalculateTime = 5000;
		public double ucb1Coef = 60.0f;
		public int mcSearchDepth = 100;
		public int mcOpSearchDepth = 70;
		public int maxOpOnePlayOutTimes = 2000;
		public int maxOnePlayOutTimes = 6000;

		public Random rnd = null;
		public UCTNode root = null;


		//CHOOSE, CONCEDE, END_TURN, HERO_ATTACK, HERO_POWER, MINION_ATTACK, PLAY_CARD
		List<PlayerTaskType> availableOptionTypes = new List<PlayerTaskType>();
		List<PlayerTaskType> availableOpOptionTypes = new List<PlayerTaskType>();

		
		public int[,] BoardCoef = new int[10, 21];
		public int[] MinionsCoef = new int[11];


		public Stopwatch watch = null;


		public UCTSimulator(double[] Coefs)
		{
			this.rnd = new Random();

			this.watch = new Stopwatch();

			SetCoefs(Coefs);

			availableOptionTypes.Add(PlayerTaskType.CHOOSE);
			availableOptionTypes.Add(PlayerTaskType.HERO_ATTACK);
			availableOptionTypes.Add(PlayerTaskType.HERO_POWER);
			availableOptionTypes.Add(PlayerTaskType.MINION_ATTACK);
			availableOptionTypes.Add(PlayerTaskType.PLAY_CARD);

			availableOpOptionTypes.Add(PlayerTaskType.HERO_ATTACK);
			availableOpOptionTypes.Add(PlayerTaskType.HERO_POWER);
			availableOpOptionTypes.Add(PlayerTaskType.MINION_ATTACK);

		}

		public UCTNode Root(SabberStoneCoreAi.POGame.POGame poGame)
		{
			return new UCTNode(poGame);
		}

		public UCTNode Root(UCTNode node)
		{
			node.option = null;
			node.parent = null;
			node.nj = 0;
			node.j = 0;
			return node;
		}

		public void SetCoefs(double[] X)
		{
			int index = 0;
			ucb1Coef = X[index++];
			mcSearchDepth = (int)X[index++];
			mcOpSearchDepth = (int)X[index++];
			maxOpOnePlayOutTimes = (int)X[index++];
			maxOnePlayOutTimes = (int)X[index++];
			for (int i = 0; i < 10; i++)
			{
				for (int j = 0; j < 21; j++)
				{
					BoardCoef[i, j] = (int)X[index++];
				}
			}

			for (int i = 0; i < 11; i++)
			{
				MinionsCoef[i] = (int)X[index++];
			}
		}

		public double UCBValue(UCTNode node)
		{
			return UCBValue(node.reward, node.nj, node.parent.N, ucb1Coef);
		}

		public double UCBValue(double reward, int nj, int N, double c)
		{
			return reward / nj + c * (Math.Sqrt((2 * Math.Log(N)) / nj));
		}

		public PlayerTask GetBestOption(UCTNode node, double rootUCTValue, out UCTNode bestSimulatedNode)
		{
			PlayerTask bestOption = GetEndTurnOption(node);
			UCTNode tmpBestSimulatedNode = null;
			double bestUCTValue = Double.MinValue;
			if (bestOption != null)
			{
				tmpBestSimulatedNode = root;
				bestUCTValue = rootUCTValue;
			}
			foreach (KeyValuePair<int, UCTNode> item in node.childDict)
			{
				double uctValue = UCBValue(item.Value);
				if (uctValue > bestUCTValue)
				{
					bestUCTValue = uctValue;
					tmpBestSimulatedNode = item.Value;
					bestOption = item.Value.option;
				}
			}
			bestSimulatedNode = tmpBestSimulatedNode;
			return bestOption;
		}

		public UCTNode GetBestChildUCTNode(UCTNode node)
		{
			PlayerTask bestOption = null;
			UCTNode bestSimulatedNode = null;
			double bestUCTValue = Double.MinValue;
			foreach (KeyValuePair<int, UCTNode> item in node.childDict)
			{
				double uctValue = UCBValue(item.Value);
				if (uctValue > bestUCTValue)
				{
					bestUCTValue = uctValue;
					bestSimulatedNode = item.Value;
					bestOption = item.Value.option;
				}
			}
			return bestSimulatedNode;
		}

		public UCTNode GetWorstChildUCTNode(UCTNode node)
		{
			PlayerTask worstOption = null;
			UCTNode worstNode = null;
			double worstUCTValue = Double.MaxValue;
			foreach (KeyValuePair<int, UCTNode> item in node.childDict)
			{
				double uctValue = UCBValue(item.Value);
				if (uctValue < worstUCTValue)
				{
					worstUCTValue = uctValue;
					worstNode = item.Value;
					worstOption = item.Value.option;
				}
			}
			return worstNode;
		}

		public PlayerTask Simulate(SabberStoneCoreAi.POGame.POGame poGame)
		{
			if (root == null ||
				!poGame.FullPrint().Equals(root.currentPOGame.FullPrint()))
				this.root = Root(poGame);

			if (root.IsCurrentPlayerTurnEnd())
				return root.currentPOGame.CurrentPlayer.Options()[0];
			if (root.IsGameOver())
				return root.currentPOGame.CurrentPlayer.Options()[0];

			double reward = 0;
			int onePlayoutTimes = 0;
			long startMilliseconds = DateTimeOffset.Now.ToUnixTimeMilliseconds();


			UCTNode currentNode = root;

			while (onePlayoutTimes < maxOnePlayOutTimes
				&& DateTimeOffset.Now.ToUnixTimeMilliseconds() - startMilliseconds < this.maxOptionCalculateTime
				&& this.watch.ElapsedMilliseconds / 1000 + 1 < poGame.CurrentPlayer.TimeOut
				)
			{
				UCTNode currentPlayerLeafNode = OnePlayOut(currentNode, availableOptionTypes);

				reward = EvaluateUCTNode(currentPlayerLeafNode);

				UpdateReward(currentPlayerLeafNode, reward);

				onePlayoutTimes++;
			}
			reward = EvaluateUCTNode(root);
			UCTNode bestChild = null;
			PlayerTask bestOption = GetBestOption(root,reward, out bestChild);
			if (bestOption.PlayerTaskType == PlayerTaskType.END_TURN || bestChild == null)
				root = null;
			else
				root = Root(bestChild);
			return bestOption;
		}

		public double EvaluateUCTNode(UCTNode currentPlayerLeafNode)
		{
			double reward = Double.MinValue;

			UCTNode opRootNode = SimulateEndTurn(currentPlayerLeafNode);

			if( opRootNode == null) // choice turn no endturn option
			{

			}
			else
			{
				// if no endturn option ,there is a choice option
					UCTNode bestOpNode = SimulateOppenont(opRootNode);
				if (bestOpNode == null) // oppent no avaliable option to simulate
					reward = EvaluateGameCurrentPlayer(currentPlayerLeafNode.currentPOGame);
				else // oppent have avaliable option to simulate
					reward = UCBValue(bestOpNode);
			}
			return reward;
		}
 
		public UCTNode OnePlayOut(UCTNode currentNode, List<PlayerTaskType> availableOptionTypes)
		{
			int step = 0;
			while (!currentNode.IsGameOver() &&
				AvailableOptions(currentNode, availableOptionTypes).Count() == currentNode.childDict.Count())
			{
				UCTNode bestChildNode = GetBestChildUCTNode(currentNode);
				if (bestChildNode == null)
				{
					break;
				}
				currentNode = bestChildNode;
			}
			UCTNode leafNode = MonteCarloSearch(currentNode, availableOptionTypes, step, mcSearchDepth);
			return leafNode;
		}

		public List<PlayerTask> AvailableOptions(UCTNode currentNode, List<PlayerTaskType> availableOptionTypes, bool playCards = true)
		{
			if (currentNode == null)
			{
				return new List<PlayerTask>();
			}
			if (currentNode.currentPOGame == null)
			{
				return new List<PlayerTask>();
			}
			List<PlayerTask> options = currentNode.currentPOGame.CurrentPlayer.Options(playCards);
			List<PlayerTask> availableOptions = new List<PlayerTask>();

			foreach (PlayerTask option in options)
			{
				if (availableOptionTypes.Contains(option.PlayerTaskType))
				{
					availableOptions.Add(option);
				}
			}
			return availableOptions;
		}

		public PlayerTask GetEndTurnOption(UCTNode currentNode, bool playCards = false)
		{
			List<PlayerTask> optionsList = currentNode.currentPOGame.CurrentPlayer.Options(playCards);
			foreach (PlayerTask option in optionsList)
			{
				if (option.PlayerTaskType == PlayerTaskType.END_TURN)
				{
					return option;
				}
			}
			return null;
		}

		public PlayerTask GetEndTurnOption(POGame.POGame game, bool playCards = false)
		{
			List<PlayerTask> optionsList = game.CurrentPlayer.Options(playCards);
			foreach (PlayerTask option in optionsList)
			{
				if (option.PlayerTaskType == PlayerTaskType.END_TURN)
				{
					return option;
				}
			}
			return null;
		}

		public UCTNode MonteCarloSearch(UCTNode startNode, List<PlayerTaskType> availableOptionTypes, int step, int depth)
		{
			UCTNode currentNode = startNode;
			List<PlayerTask> optionsList = AvailableOptions(currentNode, availableOptionTypes);
			while (step < depth &&
				optionsList.Count() > 0 &&
				!currentNode.IsGameOver() 
				|| GetEndTurnOption(currentNode) == null
				)
			{

				int rndOptionNo = rnd.Next(optionsList.Count());
				PlayerTask rndOption = optionsList[rndOptionNo];
				UCTNode tmpNode = currentNode.GetChild(rndOptionNo);

				//  if not existed 
				if (tmpNode == null)
				{
					// simulate the option
					POGame.POGame simulatedPOGame = SimulateOption(currentNode.currentPOGame, rndOption);
					// some time simulate option returned POGame is null
					if (simulatedPOGame == null)
					{
						break;
					}
					currentNode = currentNode.AddChild(currentNode, rndOption, rndOptionNo, simulatedPOGame);
				}
				//if j child is existed
				else
				{
					currentNode = tmpNode;
				}
				step++;

				// random select a option
				optionsList = AvailableOptions(currentNode, availableOptionTypes);

			}
			return currentNode;
		}

		public double EvaluateGameCurrentPlayer(POGame.POGame game)
		{
			MyScore aggroScore = new MyScore(this.BoardCoef,this.MinionsCoef);
			aggroScore.Controller = game.CurrentPlayer;
			return aggroScore.Rate();
		}

		public double EvaluateGameCurrentOpponent(POGame.POGame game)
		{
			MyScore aggroScore = new MyScore(this.BoardCoef, this.MinionsCoef);
			aggroScore.Controller = game.CurrentOpponent;
			return aggroScore.Rate();
		}

		public POGame.POGame SimulateOption(POGame.POGame game, PlayerTask option)
		{

			Dictionary<PlayerTask, POGame.POGame> dict = null;
			LinkedList<PlayerTask> options = null;
			POGame.POGame simulatedPOGame = null;

			options = new LinkedList<PlayerTask>();
			options.AddLast(option);
			try
			{
				dict = game.Simulate(options.ToList<PlayerTask>());
			}
			catch (Exception e)
			{
				return null;
			}
			dict.TryGetValue(option, out simulatedPOGame);
			return simulatedPOGame;
		}

		public UCTNode SimulateEndTurn(UCTNode currentNode)
		{
			PlayerTask endTurnOption = GetEndTurnOption(currentNode);
			POGame.POGame simulatedPOGame = null;
			if (endTurnOption == null) return null;
			simulatedPOGame = SimulateOption(currentNode.currentPOGame, endTurnOption);
			UCTNode opRootNode = new UCTNode(0, 0, 0, 0, null, endTurnOption, simulatedPOGame, new Dictionary<int, UCTNode>());
			return opRootNode;
		}

		public UCTNode SimulateOppenont(UCTNode currentNode)
		{
			UCTNode opRootNode = currentNode;
			int opOnePlayoutTimes = 0;
			while (opOnePlayoutTimes < maxOpOnePlayOutTimes)
			{
				UCTNode opLeafNode = OnePlayOut(currentNode, availableOpOptionTypes);
				double reward = EvaluateGameCurrentOpponent(opLeafNode.currentPOGame);
				UpdateReward(opLeafNode, reward);
				opOnePlayoutTimes++;
			}
			return GetWorstChildUCTNode(opRootNode); 
		}

		public void UpdateReward(UCTNode leafNode, double reward)
		{
			UCTNode currentNode = leafNode;
			while (currentNode.parent != null)
			{
				currentNode.UpdateReward(reward);
				currentNode = currentNode.parent;
			}
			return;
		}

	};

	

	class UCTHunter : AbstractAgent
	{

		public UCTHunter (){
			deck = DeathrattleHunterWang;
			hero = CardClass.HUNTER;
		}

		public static List<Card> DeathrattleHunterWang => new List<Card>()
				{
					Cards.FromName("Tracking"),
					Cards.FromName("Baron Rivendare"),
					Cards.FromName("Spiritsinger Umbra"),
					Cards.FromName("Deathstalker Rexxar"),
					Cards.FromName("Haunted Creeper"),
					Cards.FromName("Haunted Creeper"),
					Cards.FromName("Nerubian Egg"),
					Cards.FromName("Nerubian Egg"),
					Cards.FromName("Feign Death"),
					Cards.FromName("Feign Death"),
					Cards.FromName("Glaivezooka"),
					Cards.FromName("Glaivezooka"),
					Cards.FromName("Quick Shot"),
					Cards.FromName("Quick Shot"),
					Cards.FromName("Spawn of N'Zoth"),
					Cards.FromName("Spawn of N'Zoth"),
					Cards.FromName("Runic Egg"),
					Cards.FromName("Runic Egg"),
					Cards.FromName("Devilsaur Egg"),
					Cards.FromName("Devilsaur Egg"),
					Cards.FromName("Terrorscale Stalker"),
					Cards.FromName("Terrorscale Stalker"),
					Cards.FromName("Play Dead"),
					Cards.FromName("Play Dead"),
					Cards.FromName("Stitched Tracker"),
					Cards.FromName("Stitched Tracker"),
					Cards.FromName("Meat Wagon"),
					Cards.FromName("Meat Wagon"),
					Cards.FromName("Carnivorous Cube"),
					Cards.FromName("Carnivorous Cube")
				};
		
		private Random Rnd = new Random();
		UCTSimulator simulator = null;
		//public static List<Card> MyAllStandard = Cards.All.Where(c => c.Collectible && Cards.StandardSets.Contains(c.Set)).ToList();
		public static List<Card> DeathrattleHunter => new List<Card>()
		{
			Cards.FromName("Tracking"),
			Cards.FromName("Baron Rivendare"),
			Cards.FromName("Spiritsinger Umbra"),
			Cards.FromName("Deathstalker Rexxar"),
			Cards.FromName("Haunted Creeper"),
			Cards.FromName("Haunted Creeper"),
			Cards.FromName("Nerubian Egg"),
			Cards.FromName("Nerubian Egg"),
			Cards.FromName("Feign Death"),
			Cards.FromName("Feign Death"),
			Cards.FromName("Glaivezooka"),
			Cards.FromName("Glaivezooka"),
			Cards.FromName("Quick Shot"),
			Cards.FromName("Quick Shot"),
			Cards.FromName("Spawn of N'Zoth"),
			Cards.FromName("Spawn of N'Zoth"),
			Cards.FromName("Runic Egg"),
			Cards.FromName("Runic Egg"),
			Cards.FromName("Devilsaur Egg"),
			Cards.FromName("Devilsaur Egg"),
			Cards.FromName("Terrorscale Stalker"),
			Cards.FromName("Terrorscale Stalker"),
			Cards.FromName("Play Dead"),
			Cards.FromName("Play Dead"),
			Cards.FromName("Stitched Tracker"),
			Cards.FromName("Stitched Tracker"),
			Cards.FromName("Meat Wagon"),
			Cards.FromName("Meat Wagon"),
			Cards.FromName("Carnivorous Cube"),
			Cards.FromName("Carnivorous Cube")
		};


		public override void InitializeAgent()
		{
			

			//simulator = new UCTSimulator(MyProgram.currentX);
			simulator = new UCTSimulator(UCTSimulator.Coefs[UCTSimulator.CurrentPredictOpDeckIndex]);
		}

		public override void FinalizeAgent()
		{
			//Nothing to do here
		}

		public override void FinalizeGame()
		{
			//Nothing to do here
		}

		//public string PrintOpponentPlayHistory(POGame.POGame poGame)
		//{
		//	StringBuilder sb = new StringBuilder();
		//	sb.Append(MyProgram.CurrentDeckIndex);
		//	sb.Append(",");
		//	sb.Append(poGame.CurrentOpponent.Hero.Card.AssetId);
		//	sb.Append(",");
		//	int index = 1;
		//	foreach (PlayHistoryEntry entry in poGame.CurrentOpponent.PlayHistory)
		//	{
		//		if (index > 30)
		//			break;
		//		sb.Append(entry.SourceCard.AssetId);
		//		sb.Append(",");
		//		index++;
		//	}
		//	while (index < 31)
		//	{
		//		sb.Append(0);
		//		sb.Append(",");
		//		index++;
		//	}
		//	return sb.ToString();
		//}

		public void PredictOppDeck(POGame.POGame poGame)
		{
			double[] playHis = new double[31];
			int index = 0;
			playHis[index] = poGame.CurrentOpponent.Hero.Card.AssetId;
			index++;
			foreach (PlayHistoryEntry entry in poGame.CurrentOpponent.PlayHistory)
			{
				if (index > 30)
					break;
				playHis[index] = (entry.SourceCard.AssetId);
				index++;
			}
			while (index < 31)
			{
				playHis[index] = 0;
				index++;
			}
			UCTSimulator.CurrentPredictOpDeckIndex = 0;
			simulator.SetCoefs(UCTSimulator.Coefs[UCTSimulator.CurrentPredictOpDeckIndex]);
		}

		public override PlayerTask GetMove(SabberStoneCoreAi.POGame.POGame poGame)
		{
			if (!simulator.watch.IsRunning)
			{
				simulator.watch.Reset();
				simulator.watch.Start();

				//if ((poGame.CurrentPlayer == poGame.FirstPlayer) == MyProgram.IsTestPlayerA)
				//{
				//	Log.Instance("trainhistory0708.txt").Append(PrintOpponentPlayHistory(poGame));
				//}
				//else
				//{
				//	simulator.SetCoefs(MyProgram.basecoef);
				//}

				//PredictOppDeck(poGame);
			}
			PlayerTask bestOption = null;
			try
			{
				bestOption = simulator.Simulate(poGame);
			}
			catch (Exception e)
			{
				bestOption = getRndMove(poGame);
			}
			if (bestOption.PlayerTaskType == PlayerTaskType.END_TURN)
			{
				simulator.watch.Stop();
			}

			return bestOption;
		}

		public override void InitializeGame()
		{
			//Nothing to do here
		}

		// second plan
		public PlayerTask getRndMove(SabberStoneCoreAi.POGame.POGame poGame)
		{
			List<PlayerTask> options = poGame.CurrentPlayer.Options();
			return options[0];
		}

	}
}
